@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procuid.h,v 1.28 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_PROC_UID_UID		0
 #define GLIBTOP_PROC_UID_EUID		1
@@ -47,39 +45,42 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_PROC_UID_TPGID		13
 #define GLIBTOP_PROC_UID_PRIORITY	14
 #define GLIBTOP_PROC_UID_NICE		15
-#define GLIBTOP_PROC_UID_NGROUPS	16
-#define GLIBTOP_PROC_UID_GROUPS		17
+#define GLIBTOP_PROC_UID_NGROUPS    16
+#define GLIBTOP_PROC_UID_GROUPS     17
 
 #define GLIBTOP_MAX_PROC_UID		18
 
 typedef struct _glibtop_proc_uid	glibtop_proc_uid;
 
+#define GLIBTOP_MAX_GROUPS          64
+
 /* User, Group, Terminal and session */
 
 struct _glibtop_proc_uid
 {
-    u_int64_t flags;
-    int uid,		/* user id */
-	euid,		/* effective user id */
-	gid,		/* group id */
-	egid,		/* effective group id */
-	suid,		/* saved user id */
-	sgid,		/* saved group id */
-	fsuid,		/* file system user id */
-	fsgid,		/* file system group id */
-	pid,		/* process id */
-	ppid,		/* pid of parent process */
-	pgrp,		/* process group id */
-	session,	/* session id */
-	tty,		/* full device number of controlling terminal */
-	tpgid,		/* terminal process group id */
-	priority,	/* kernel scheduling priority */
-	nice,		/* standard unix nice level of process */
-	ngroups,	/* number of additional process groups */
-	groups [GLIBTOP_MAX_GROUPS];	/* additional prcess groups */
+	guint64 flags;
+	gint32 uid,		/* user id */
+		euid,		/* effective user id */
+		gid,		/* group id */
+		egid,		/* effective group id */
+        suid,       /* set user id */
+        sgid,       /* set group id */
+        fsuid,      /* ??? user id */
+        fsgid,      /* ??? group id */
+		pid,		/* process id */
+		ppid,		/* pid of parent process */
+		pgrp,		/* process group id */
+		session,	/* session id */
+		tty,		/* full device number of controlling terminal */
+		tpgid,		/* terminal process group id */
+		priority,	/* kernel scheduling priority */
+		nice,		/* standard unix nice level of process */
+		ngroups,
+        groups [GLIBTOP_MAX_GROUPS];
+
 };
 
-#define glibtop_get_proc_uid(p1, p2)	glibtop_get_proc_uid_l(glibtop_global_server, p1, p2)
+void glibtop_get_proc_uid(glibtop_proc_uid *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_UID
 #define glibtop_get_proc_uid_r		glibtop_get_proc_uid_p
@@ -87,27 +88,17 @@ struct _glibtop_proc_uid
 #define glibtop_get_proc_uid_r		glibtop_get_proc_uid_s
 #endif
 
-int glibtop_get_proc_uid_l (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
+void glibtop_get_proc_uid_l (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_UID
-int glibtop_init_proc_uid_p (glibtop *server);
-int glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
+void glibtop_init_proc_uid_p (glibtop *server);
+void glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
 #else
-int glibtop_init_proc_uid_s (glibtop *server);
-int glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
+void glibtop_init_proc_uid_s (glibtop *server);
+void glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
 #endif
 
-#ifdef GLIBTOP_NAMES
 
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proc_uid [];
-extern const unsigned glibtop_types_proc_uid [];
-extern const char *glibtop_labels_proc_uid [];
-extern const char *glibtop_descriptions_proc_uid [];
-
-#endif
-
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
