@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.27 2004/07/03 13:28:59 bdejean Exp $ */
+/* $Id: swap.c,v 1.29 2005/06/13 09:03:41 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -25,6 +25,8 @@
 #include <glibtop/error.h>
 #include <glibtop/swap.h>
 
+#include "glibtop_private.h"
+
 #include <fcntl.h>
 
 static const unsigned long _glibtop_sysdeps_swap =
@@ -47,6 +49,7 @@ glibtop_init_swap_s (glibtop *server)
 
 #define MEMINFO		"/proc/meminfo"
 #define PROC_STAT	"/proc/stat"
+#define PROC_VMSTAT	"/proc/vmstat"
 
 void
 glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
@@ -67,15 +70,38 @@ glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
 
 	buf->flags = _glibtop_sysdeps_swap;
 
-	file_to_buffer(server, buffer, PROC_STAT);
 
-	p = strstr (buffer, "\nswap");
-	if (p == NULL) return;
+	if(server->os_version_code >= LINUX_VERSION_CODE(2, 6, 0))
+	{
+		file_to_buffer (server, buffer, PROC_VMSTAT);
 
-	p = skip_token (p);
+		p = strstr (buffer, "\npswpin");
 
-	buf->pagein  = strtoull (p, &p, 0);
-	buf->pageout = strtoull (p, &p, 0);
+		if(p)
+		{
+			p = skip_token(p);
+			buf->pagein  = strtoull (p, &p, 0);
 
-	buf->flags |= _glibtop_sysdeps_swap_paging;
+			p = skip_token(p);
+			buf->pageout  = strtoull (p, &p, 0);
+
+			buf->flags |= _glibtop_sysdeps_swap_paging;
+		}
+	}
+	else /* Linux 2.4 */
+	{
+		file_to_buffer (server, buffer, PROC_STAT);
+
+		p = strstr (buffer, "\nswap");
+
+		if(p)
+		{
+			p = skip_token (p);
+
+			buf->pagein  = strtoull (p, &p, 0);
+			buf->pageout = strtoull (p, &p, 0);
+
+			buf->flags |= _glibtop_sysdeps_swap_paging;
+		}
+	}
 }
